@@ -1,12 +1,13 @@
 use extendr_api::prelude::*;
 use std::cmp::min;
+use std::vec::Vec;
 
 /// Calculate STARS RSI points and return to R as a vector
 /// @param vals The column we are measuring change on
 /// @param t_crit The critical value of a t-distribution at the desired p-value
 /// @param l The cut-off length of a regime; affects sensitivity
-#[extendr(use_try_from = true)]
-fn rust_rodionov(vals: &[f64], t_crit: f64, l: usize) -> std::vec::Vec<f64> {
+#[extendr]
+fn rust_rodionov(vals: &[f64], t_crit: f64, l: usize) -> Vec<f64> {
     let mut results = vec![0.; l];
 
     // calculate sigma^2_l
@@ -102,10 +103,43 @@ fn calculate_rsi(regime: &[f64], shift_boundary: &f64, is_down: bool, l: &f64, v
     rsi
 }
 
+
+/// Calculates the mean for each regime in a regime shift analysis.
+/// @param col The column we are measuring change on.
+/// @param rsi The column containing RSI values.
+#[extendr]
+fn rust_regime_means(col: &[f64], rsi: &[f64]) -> Vec<f64> {
+    let mut means: Vec<f64> = Vec::new();
+    let mut current_regime: Vec<f64> = Vec::new();
+    let mut regime_mean: f64;
+    let mut regime_length: usize;
+
+    for i in 0..col.len() {
+        if rsi[i] == 0. {
+            // add to current regime
+            current_regime.push(col[i]);
+        } else {
+            // new regime starts: calculate mean of last regime
+            regime_length = current_regime.len();
+            regime_mean = current_regime.drain(..).sum::<f64>() / regime_length as f64;
+            means.append(&mut [regime_mean].repeat(regime_length));
+            current_regime.push(col[i])
+        }
+    }
+    // calculate means for final regime
+    regime_length = current_regime.len();
+    regime_mean = current_regime.drain(..).sum::<f64>() / regime_length as f64;
+    means.append(&mut [regime_mean].repeat(regime_length));
+
+    means
+}
+
+
 // Macro to generate exports.
 // This ensures exported functions are registered with R.
 // See corresponding C code in `entrypoint.c`.
 extendr_module! {
     mod rshift;
     fn rust_rodionov;
+    fn rust_regime_means;
 }
